"""
MetricsFirst SDK for Python
Track analytics for your Telegram bots
"""

from .client import MetricsFirst
from .async_client import AsyncMetricsFirst
from .types import (
    CommandEventData,
    InteractionEventData,
    InteractionType,
    ServiceEventData,
    ErrorEventData,
    ErrorSeverity,
    PurchaseEventData,
    PurchaseStatus,
    RecurringChargeEventData,
    UserIdentifyData,
)

__version__ = "0.1.0"
__all__ = [
    "MetricsFirst",
    "AsyncMetricsFirst",
    "CommandEventData",
    "InteractionEventData",
    "InteractionType",
    "ServiceEventData",
    "ErrorEventData",
    "ErrorSeverity",
    "PurchaseEventData",
    "PurchaseStatus",
    "RecurringChargeEventData",
    "UserIdentifyData",
]

